#include "Arduino.h"
#include "Morse.h"

/**
	Simple C++ class for sending Morse code flashes by switching a pin on and off
	Ian Johnson - Wolfram Research 2015
*/


Morse::Morse(int pin,int time_unit)
{
	pinMode(pin,OUTPUT);
	_unit=time_unit;
	_pin=pin;
}

void Morse::dot()
{
	//this is in case the user uses the pin themselves and configures the pin to be an input
	pinMode(_pin,OUTPUT);
	digitalWrite(_pin,HIGH);
	delay(_unit);
	digitalWrite(_pin,LOW);
	delay(_unit);
}

void Morse::dash()
{
	//see comment in dot method concerning the pinMode call
	pinMode(_pin,OUTPUT);
	digitalWrite(_pin,HIGH);
	//for dash we wait 3 times as long
	delay(3*_unit);
	digitalWrite(_pin,LOW);
	delay(_unit);
}

void Morse::morseCoder(char * string)
{
	unsigned int index =0;
	//for each character in the string, switch on which specific character it is and run that sequence
  	for (index=0;index<strlen(string);index++)
  	{
    	switch (string[index])
    	{
		    case 'a':
			case 'A':
		        dot();
		        dash();
				//for full strings, we use two blank spaces as the delimiter between letters
		        delay(2*_unit);
		        break;
		    case 'b':
		    case 'B':
		        dash();
		        dot();
		        dot();
		        dot();
		        delay(2*_unit);
		        break;
		    case 'c':
		    case 'C':
		        dash();
		        dot();
		        dash();
		        dot();
		        delay(2*_unit);
		        break;
		    case 'd':
		    case 'D':
		        dash();
		        dot();
		        dot();
		        delay(2*_unit);
		        break;
		    case 'e':
		    case 'E':
		        dot();
		        delay(2*_unit);
		        break;
		    case 'f':
		    case 'F':
		        dot();
		        dot();
		        dash();
		        dot();
		        delay(2*_unit);
		        break;
		    case 'g':
		    case 'G':
		        dash();
		        dash();
		        dot();
		        delay(2*_unit);
		        break;
		    case 'h':
		    case 'H':
		        dot();
		        dot();
		        dot();
		        dot();
		        delay(2*_unit);
		        break;
		    case 'i':
		    case 'I':
		        dot();
		        dot();
		        delay(2*_unit);
		        break;
		    case 'j':
		    case 'J':
		        dot();
		        dash();
		        dash();
		        dash();
		        delay(2*_unit);
		        break;
		    case 'k':
		    case 'K':
		        dash();
		        dot();
		        dash();
		        delay(2*_unit);
		        break;
		    case 'l':
		    case 'L':
		        dot();
		        dash();
		        dot();
		        dot();
		        delay(2*_unit);
		        break;
		    case 'm':
		    case 'M':
		        dash();
		        dash();
		        delay(2*_unit);
		        break;
		    case 'n':
		    case 'N':
		        dash();
		        dot();
		        delay(2*_unit);
		        break;
		    case 'o':
		    case 'O':
		        dash();
		        dash();
		        dash();
		        delay(2*_unit);
		        break;
		    case 'p':
		    case 'P':
		        dot();
		        dash();
		        dash();
		        dot();
		        delay(2*_unit);
		        break;
		    case 'q':
		    case 'Q':
		        dash();
		        dash();
		        dot();
		        dash();
		        delay(2*_unit);
		        break;
		    case 'r':
		    case 'R':
		        dot();
		        dash();
		        dot();
		        delay(2*_unit);
		        break;
		    case 's':
		    case 'S':
		        dot();
		        dot();
		        dot();
		        delay(2*_unit);
		        break;
		    case 't':
		    case 'T':
		        dash();
		        delay(2*_unit);
		        break;
		    case 'u':
		    case 'U':
		        dot();
		        dot();
		        dash();
		        delay(2*_unit);
		        break;
		    case 'v':
		    case 'V':
		        dot();
		        dot();
		        dot();
		        dash();
		        delay(2*_unit);
		        break;
		    case 'w':
		    case 'W':
		        dot();
		        dash();
		        dash();
		        delay(2*_unit);
		        break;
		    case 'x':
		    case 'X':
		        dash();
		        dot();
		        dot();
		        dash();
		        delay(2*_unit);
		        break;
		    case 'y':
		    case 'Y':
		        dash();
		        dot();
		        dash();
		        dash();
		        delay(2*_unit);
		        break;
		    case 'z':
		    case 'Z':
		        dash();
		        dash();
		        dot();
		        dot();
		        delay(2*_unit);
		        break;
		    case ' ':
		        delay(4*_unit);
		        break;
		    case '1':
		        dot();
		        dash();
		        dash();
		        dash();
		        dash();
		        delay(2*_unit);
		        break;
		    case '2':
		        dot();
		        dot();
		        dash();
		        dash();
		        dash();
		        delay(2*_unit);
		        break;
		    case '3':
		        dot();
		        dot();
		        dot();
		        dash();
		        dash();
		        delay(2*_unit);
		        break;
		    case '4':
		        dot();
		        dot();
		        dot();
		        dot();
		        dash();
		        delay(2*_unit);
		        break;
		    case '5':
		        dot();
		        dot();
		        dot();
		        dot();
		        dot();
		        delay(2*_unit);
		        break;
		    case '6':
		        dash();
		        dot();
		        dot();
		        dot();
		        dot();
		        delay(2*_unit);
		        break;
		    case '7':
		        dash();
		        dash();
		        dot();
		        dot();
		        dot();
		        delay(2*_unit);
		        break;
		    case '8':
		        dash();
		        dash();
		        dash();
		        dot();
		        dot();
		        delay(2*_unit);
		        break;
		    case '9':
		        dash();
		        dash();
		        dash();
		        dash();
		        dot();
	        	delay(2*_unit);
	        	break;
	      	case '0':
	        	dash();
	    	    dash();
		        dash();
	        	dash();
	        	dash();
	        	delay(2*_unit);
	        	break;
			default:
				break;
		}
	}
  
}
